[![wq.app][logo]][docs]

[**wq.app**][docs] is a suite of JavaScript modules created to facilitate the rapid deployment of offline-capable mobile and desktop data collection apps.  Potential use cases include **surveys**, **geographic data capture & management**, and **crowdsourcing**/**citizen science**.  wq.app is the client component of the [wq framework], and can be used with a [wq.db] server or adapted for use with any API.

[![Latest PyPI Release](https://img.shields.io/pypi/v/wq.app.svg)](https://pypi.org/project/wq.app)
[![Release Notes](https://img.shields.io/github/release/wq/wq.app.svg)](https://github.com/wq/wq.app/releases)
[![Documentation](https://img.shields.io/badge/Docs-1.3-blue.svg)][docs]
[![License](https://img.shields.io/pypi/l/wq.app.svg)](https://wq.io/license)
[![GitHub Stars](https://img.shields.io/github/stars/wq/wq.app.svg)](https://github.com/wq/wq.app/stargazers)
[![GitHub Forks](https://img.shields.io/github/forks/wq/wq.app.svg)](https://github.com/wq/wq.app/network)
[![GitHub Issues](https://img.shields.io/github/issues/wq/wq.app.svg)](https://github.com/wq/wq.app/issues)

[![Package Tests](https://github.com/wq/wq.app/actions/workflows/test.yml/badge.svg)](https://github.com/wq/wq.app/actions/workflows/test.yml)

### [Documentation][docs]

[**Installation**][installation]

[**API**][api]
<br>
[@wq/app]
&bull;
[@wq/store]
&bull;
[@wq/model]
&bull;
[@wq/router]
&bull;
[@wq/outbox]

[**Plugins**][plugins]
<br>
[@wq/react]
&bull;
[@wq/material]
&bull;
[@wq/map]
&bull;
[@wq/map-gl]

**Legacy Plugins**
<br>
[@wq/jquery-mobile]
&bull;
[@wq/leaflet]

[logo]: https://wq.io/images/wq.app.svg
[docs]: https://wq.io/wq.app/

[installation]: https://wq.io/wq.app/#installation
[api]: https://wq.io/wq.app/#api
[@wq/app]: https://wq.io/@wq/app
[@wq/store]: https://wq.io/@wq/store
[@wq/model]: https://wq.io/@wq/model
[@wq/router]: https://wq.io/@wq/router
[@wq/outbox]: https://wq.io/@wq/outbox
[plugins]: https://wq.io/plugins/
[@wq/react]: https://wq.io/@wq/react
[@wq/material]: https://wq.io/@wq/material
[@wq/map]: https://wq.io/@wq/map
[@wq/map-gl]: https://wq.io/@wq/map-gl

[@wq/jquery-mobile]: https://github.com/wq/wq.app/tree/main/packages/jquery-mobile
[@wq/leaflet]: https://github.com/wq/wq.app/tree/main/packages/leaflet

[wq framework]: https://wq.io/
[wq.db]: https://wq.io/wq.db/
